@@ -1,9 +1,9 @@
-# Last modified 21 Oct 2011.
+# Last modified 23 Apr 2012.
 
-estimateGLMTagwiseDisp <- function(y, design, offset=NULL, ...) 
+estimateGLMTagwiseDisp <- function(y, design=NULL, offset=NULL, ...) 
 UseMethod("estimateGLMTagwiseDisp")
 
-estimateGLMTagwiseDisp.DGEList <- function(y, design, offset=NULL, trend=!is.null(y$trended.dispersion), ...)
+estimateGLMTagwiseDisp.DGEList <- function(y, design=NULL, offset=NULL, trend=!is.null(y$trended.dispersion), ...)
 {
 	if(is.null(offset)) offset <- getOffset(y)
 	if(trend)  {
@@ -18,7 +18,19 @@ estimateGLMTagwiseDisp.DGEList <- function(y, design, offset=NULL, trend=!is.nul
 	y
 }
 
-estimateGLMTagwiseDisp.default <- function(y, design, offset=NULL, dispersion, trend="TRUE", ...)
+estimateGLMTagwiseDisp.default <- function(y, design=NULL, offset=NULL, dispersion, trend="TRUE", ...)
 {
+	y <- as.matrix(y)
+	if(is.null(design)) {
+		design <- matrix(1,ncol(y),1)
+		rownames(design) <- colnames(y)
+		colnames(design) <- "Intercept"
+	} else {
+		design <- as.matrix(design)
+	}
+	if(ncol(design) >= ncol(y)) {
+		warning("No residual df: setting dispersion to NA")
+		return(NA,nrow(y))
+	}
 	dispCoxReidInterpolateTagwise(y, design, offset=offset, dispersion, trend=trend, ...)
 }
